==> Syllabus_RL-0.4-py3-none-any.whl: syllabus/examples/task_wrappers/procgen_task_wrapper.py <==
import gym
import numpy as np
from syllabus.core import TaskWrapper
from syllabus.task_space import TaskSpace


class ProcgenTaskWrapper(TaskWrapper):
    """
    This wrapper allows you to change the task of an NLE environment.
    """
    def __init__(self, env: gym.Env, seed=0):
        super().__init__(env)
        self.task_space = TaskSpace(gym.spaces.Discrete(200), list(np.arange(0, 200)))
        self.task = seed
        self.seed(seed)

        self.observation_space = self.env.observation_space

    def seed(self, seed):
        self.env.unwrapped._venv.seed(seed, 0)

    def reset(self, new_task=None, **kwargs):
        """
        Resets the environment along with all available tasks, and change the current task.

        This ensures that all instance variables are reset, not just the ones for the current task.
        We do this efficiently by keeping track of which reset functions have already been called,
        since very few tasks override reset. If new_task is provided, we change the task before
        calling the final reset.
        """
        # Change task if new one is provided
        if new_task is not None:
            self.change_task(new_task)

        self.done = False
        self.episode_return = 0

        return self.observation(self.env.reset(**kwargs))

    def change_task(self, new_task: int):
        """
        Change task by directly editing environment class.

        Ignores requests for unknown tasks or task changes outside of a reset.
        """
        seed = int(new_task)
        self.task = seed
        self.seed(seed)

    def step(self, action):
        """
        Step through environment and update task completion.
        """
        obs, rew, done, info = self.env.step(action)
        return self.observation(obs), rew, done, info

    def observation(self, obs):
        return obs

==> Syllabus_RL-0.5-py3-none-any.whl: syllabus/examples/task_wrappers/procgen_task_wrapper.py <==
import gymnasium as gym
import numpy as np
from syllabus.core import TaskWrapper
from syllabus.task_space import TaskSpace


PROCGEN_RETURN_BOUNDS = {
    "coinrun": (5, 10),
    "starpilot": (2.5, 64),
    "caveflyer": (3.5, 12),
    "dodgeball": (1.5, 19),
    "fruitbot": (-1.5, 32.4),
    "chaser": (0.5, 13),
    "miner": (1.5, 13),
    "jumper": (3, 10),
    "leaper": (3, 10),
    "maze": (5, 10),
    "bigfish": (1, 40),
    "heist": (3.5, 10),
    "climber": (2, 12.6),
    "plunder": (4.5, 30),
    "ninja": (3.5, 10),
    "bossfight": (0.5, 13),
}


class ProcgenTaskWrapper(TaskWrapper):
    """
    This wrapper allows you to change the task of an NLE environment.
    """
    def __init__(self, env: gym.Env, seed=0):
        super().__init__(env)
        self.task_space = TaskSpace(gym.spaces.Discrete(200), list(np.arange(0, 200)))
        self.task = seed
        self.seed(seed)
        self.episode_return = 0

        self.observation_space = self.env.observation_space

    def seed(self, seed):
        self.env.gym_env.unwrapped._venv.seed(seed, 0)

    def reset(self, new_task=None, **kwargs):
        """
        Resets the environment along with all available tasks, and change the current task.

        This ensures that all instance variables are reset, not just the ones for the current task.
        We do this efficiently by keeping track of which reset functions have already been called,
        since very few tasks override reset. If new_task is provided, we change the task before
        calling the final reset.
        """
        self.episode_return = 0.0

        # Change task if new one is provided
        if new_task is not None:
            self.change_task(new_task)

        obs, info = self.env.reset(**kwargs)
        return self.observation(obs), info

    def change_task(self, new_task: int):
        """
        Change task by directly editing environment class.

        Ignores requests for unknown tasks or task changes outside of a reset.
        """
        seed = int(new_task)
        self.task = seed
        self.seed(seed)

    def step(self, action):
        """
        Step through environment and update task completion.
        """
        obs, rew, term, trunc, info = self.env.step(action)
        self.episode_return += rew

        env_min, env_max = PROCGEN_RETURN_BOUNDS[self.env_id]
        normalized_return = (self.episode_return - env_min) / (env_max - env_min)
        info["task_completion"] = normalized_return

        return self.observation(obs), rew, term, trunc, info

    def observation(self, obs):
        return obs
